# Secbench framework (`secbench-picoscope` package)

The `secbench-picoscope` contains drivers for Picoscope devices compatible with `secbench-api`.

For getting started, please refer to the [documentation of the secbench framework](https://doc.secbench.fr), or the [source repository](https://github.com/CEA-Leti/secbench).

This project is licensed under [CECILL-2.1](http://www.cecill.info/index.en.html) (see LICENSE).